<!-- CHUNK ID: chunk_451D1544  CHUNK TYPE: header START_LINE:1 -->
### Getting Started

<!-- CHUNK ID: chunk_5534569E  CHUNK TYPE: paragraph START_LINE:3 -->
PDFMathTranslate is a powerful PDF translation tool. You can install and start using this tool in various ways.

<!-- CHUNK ID: h_rule_176d4d55  CHUNK TYPE: h_rule START_LINE:5 -->
---

<!-- CHUNK ID: chunk_36D1B1ED  CHUNK TYPE: header START_LINE:7 -->
### Installation

<!-- CHUNK ID: chunk_0CAD1479  CHUNK TYPE: list START_LINE:9 -->
1. [**Windows EXE**](./INSTALLATION_winexe.md) <small>Recommand for Windows</small>
2. [**Docker**](./INSTALLATION_docker.md) <small>Recommand for Linux</small>
3. [**uv** (a Python package manager)](./INSTALLATION_uv.md) <small>Recommand for macOS</small>

<!-- CHUNK ID: h_rule_79a62a8c  CHUNK TYPE: h_rule START_LINE:13 -->
---

<!-- CHUNK ID: chunk_047D6F23  CHUNK TYPE: header START_LINE:15 -->
### Usage

<!-- CHUNK ID: chunk_3E32AB82  CHUNK TYPE: list START_LINE:17 -->
1. [Using **WebUI**](./USAGE_webui.md)
2. [Using **Zotero Plugin**](https://github.com/guaguastandup/zotero-pdf2zh) (Third party program)
3. [Using **Commandline**](./USAGE_commandline.md)
